@@ -99,7 +99,7 @@ def call_from(cluster,config,keep_qc_fails,task):
 
     svlen=util.center(v.svlen for v in leads)
 
-    if abs(svlen) < config.minsvlen:
+    if abs(svlen) < config.minsvlen_screen:
         return
 
     #Count inline events only once per read, but split events as individual alignments, as in coverage calculation
@@ -125,12 +125,15 @@ def call_from(cluster,config,keep_qc_fails,task):
     support_fwd=sum(lead.strand == "+" for lead in leads)
     support_rev=len(leads) - support_fwd
 
+    filter="PASS"
     if config.qc_strand and (support_fwd==0 or support_rev==0):
+        filter="STRAND"
         qc=False
 
     if config.qc_nm:
         nm_mean=util.mean(v.nm for v in leads)
         if nm_mean > config.qc_nm_max:
+            filter="NM"
             qc=False
     else:
         nm_mean=-1
@@ -151,7 +154,7 @@ def call_from(cluster,config,keep_qc_fails,task):
                   ref="N",
                   alt=f"<{svtype}>",
                   qual=qual,
-                  filter="PASS",
+                  filter=filter,
                   info=dict(),
                   svtype=svtype,
                   svlen=svlen,
@@ -176,6 +179,8 @@ def call_from(cluster,config,keep_qc_fails,task):
     if stdev_len!=None:
         svcall.set_info("STDEV_LEN",stdev_len)
 
+    #svcall.set_info("CLUSTER_ID",cluster.id)
+
     task.sv_id+=1
 
     yield svcall
@@ -253,19 +258,19 @@ def call_group(svgroup,config,task):
         if config.output_rnames and cand.rnames!=None:
             rnames.extend(cand.rnames)
         if not 0 in cand.genotypes:
-            cand.genotypes[0]=(".",".",0,0,cand.support)
+            cand.genotypes[0]=(".",".",0,0,cand.support,None)
         if cand.sample_internal_id in genotypes:
             #Intra-sample merging
-            a,b,gt_qual,dr,dv=cand.genotypes[0]
-            curr_a,curr_b,curr_gt_qual,curr_dr,curr_dv,curr_id=genotypes[cand.sample_internal_id]
+            a,b,gt_qual,dr,dv,ps=cand.genotypes[0]
+            curr_a,curr_b,curr_gt_qual,curr_dr,curr_dv,curr_ps,curr_id=genotypes[cand.sample_internal_id]
             new_id=curr_id+","+config.id_prefix+cand.id
             if (curr_a==".") or (a != "." and (a,b) >= (curr_a,curr_b)):
-                genotypes[cand.sample_internal_id]=(a,b,gt_qual,dr,dv,new_id)
+                genotypes[cand.sample_internal_id]=(a,b,gt_qual,dr,dv,ps,new_id)
             else:
-                genotypes[cand.sample_internal_id]=(curr_a,curr_b,curr_gt_qual,curr_dr,curr_dv,new_id)
+                genotypes[cand.sample_internal_id]=(curr_a,curr_b,curr_gt_qual,curr_dr,curr_dv,curr_ps,new_id)
         else:
-            a,b,gt_qual,dr,dv=cand.genotypes[0]
-            genotypes[cand.sample_internal_id]=(a,b,gt_qual,dr,dv,config.id_prefix+cand.id)
+            a,b,gt_qual,dr,dv,ps=cand.genotypes[0]
+            genotypes[cand.sample_internal_id]=(a,b,gt_qual,dr,dv,ps,config.id_prefix+cand.id)
         genotyped_count+=1
 
     for sample_internal_id in sample_internal_ids:
@@ -273,9 +278,9 @@ def call_group(svgroup,config,task):
             continue
         coverage=svgroup.coverages_nonincluded[sample_internal_id]
         if coverage >= config.combine_null_min_coverage:
-            genotypes[sample_internal_id]=(0,0,0,coverage,0,"NULL")
+            genotypes[sample_internal_id]=(0,0,0,coverage,0,None,"NULL")
         else:
-            genotypes[sample_internal_id]=(".",".",0,coverage,0,"NULL")
+            genotypes[sample_internal_id]=(".",".",0,coverage,0,None,"NULL")
 
     if config.combine_consensus:
         genotypes_consensus={}
@@ -294,17 +299,31 @@ def call_group(svgroup,config,task):
         if cons_a!=1 and cons_b!=1:
             return None
 
+    svcall_pos=int(util.median(cand.pos for cand in svgroup.candidates))
+    svcall_svlen=int(util.median(cand.svlen for cand in svgroup.candidates))
+    svcall_alt=first_cand.alt
+    svcall_alt_mindist=abs(len(svcall_alt)-svcall_svlen)
+    if first_cand.svtype=="INS":
+        svcall_end=svcall_pos
+        for cand in svgroup.candidates:
+            dist=abs(len(cand.alt)-svcall_svlen)
+            if dist < svcall_alt_mindist:
+                svcall_alt_mindist=dist
+                svcall_alt=cand.alt
+    else:
+        svcall_end=svcall_pos+abs(svcall_svlen)
+
     svcall=SVCall(contig=first_cand.contig,
-                  pos=util.center(cand.pos for cand in svgroup.candidates),
+                  pos=svcall_pos,
                   id=f"{first_cand.svtype}.{task.sv_id:X}M{task.id:X}",
                   ref="N",
-                  alt=first_cand.alt,
+                  alt=svcall_alt,
                   qual=round(util.mean(int(cand.qual) for cand in svgroup.candidates)),
                   filter="PASS",
                   info=dict(),
                   svtype=first_cand.svtype,
-                  svlen=util.center(cand.svlen for cand in svgroup.candidates),
-                  end=util.center(cand.end for cand in svgroup.candidates),
+                  svlen=svcall_svlen,
+                  end=svcall_end,
                   genotypes=genotypes,
                   precise=sum(int(cand.precise) for cand in svgroup.candidates)/float(len(svgroup.candidates)) > 0.5,
                   support=round(util.mean(cand.support for cand in svgroup.candidates)),
@@ -315,10 +334,15 @@ def call_group(svgroup,config,task):
                   fwd=sum(cand.fwd for cand in svgroup.candidates),
                   rev=sum(cand.rev for cand in svgroup.candidates),
                   coverage_upstream=util.mean_or_none_round(cand.coverage_upstream for cand in svgroup.candidates if cand.coverage_upstream!=None),
+                  coverage_start=util.mean_or_none_round(cand.coverage_start for cand in svgroup.candidates if cand.coverage_start!=None),
                   coverage_center=util.mean_or_none_round(cand.coverage_center for cand in svgroup.candidates if cand.coverage_center!=None),
+                  coverage_end=util.mean_or_none_round(cand.coverage_end for cand in svgroup.candidates if cand.coverage_end!=None),
                   coverage_downstream=util.mean_or_none_round(cand.coverage_downstream for cand in svgroup.candidates if cand.coverage_downstream!=None) )
 
-    if abs(svcall.svlen) < config.minsvlen:
+    svcall.set_info("STDEV_POS",util.stdev(cand.pos for cand in svgroup.candidates))
+    svcall.set_info("STDEV_LEN",util.stdev(cand.svlen for cand in svgroup.candidates))
+
+    if abs(svcall.svlen) < config.minsvlen_screen:
         return None
 
     task.sv_id+=1
